// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.


using System;
using System.Runtime.InteropServices;
using System.Runtime.CompilerServices;
using System.Text;
using Silk.NET.Core;
using Silk.NET.Core.Native;
using Silk.NET.Core.Attributes;
using Silk.NET.Core.Contexts;
using Silk.NET.Core.Loader;

#pragma warning disable 1591

namespace Silk.NET.Vulkan
{
    [NativeName("Name", "VkDescriptorPoolCreateInfo")]
    public unsafe partial struct DescriptorPoolCreateInfo : IChainStart
    {
        public DescriptorPoolCreateInfo
        (
            StructureType? sType = StructureType.DescriptorPoolCreateInfo,
            void* pNext = null,
            DescriptorPoolCreateFlags? flags = null,
            uint? maxSets = null,
            uint? poolSizeCount = null,
            DescriptorPoolSize* pPoolSizes = null
        ) : this()
        {
            if (sType is not null)
            {
                SType = sType.Value;
            }

            if (pNext is not null)
            {
                PNext = pNext;
            }

            if (flags is not null)
            {
                Flags = flags.Value;
            }

            if (maxSets is not null)
            {
                MaxSets = maxSets.Value;
            }

            if (poolSizeCount is not null)
            {
                PoolSizeCount = poolSizeCount.Value;
            }

            if (pPoolSizes is not null)
            {
                PPoolSizes = pPoolSizes;
            }
        }

/// <summary></summary>
        [NativeName("Type", "VkStructureType")]
        [NativeName("Type.Name", "VkStructureType")]
        [NativeName("Name", "sType")]
        public StructureType SType;
/// <summary></summary>
        [NativeName("Type", "void*")]
        [NativeName("Type.Name", "void")]
        [NativeName("Name", "pNext")]
        public void* PNext;
/// <summary></summary>
        [NativeName("Type", "VkDescriptorPoolCreateFlags")]
        [NativeName("Type.Name", "VkDescriptorPoolCreateFlags")]
        [NativeName("Name", "flags")]
        public DescriptorPoolCreateFlags Flags;
/// <summary></summary>
        [NativeName("Type", "uint32_t")]
        [NativeName("Type.Name", "uint32_t")]
        [NativeName("Name", "maxSets")]
        public uint MaxSets;
/// <summary></summary>
        [NativeName("Type", "uint32_t")]
        [NativeName("Type.Name", "uint32_t")]
        [NativeName("Name", "poolSizeCount")]
        public uint PoolSizeCount;
/// <summary></summary>
        [NativeName("Type", "VkDescriptorPoolSize*")]
        [NativeName("Type.Name", "VkDescriptorPoolSize")]
        [NativeName("Name", "pPoolSizes")]
        public DescriptorPoolSize* PPoolSizes;

        /// <inheritdoc />
        StructureType IStructuredType.StructureType()
        {
            return SType = StructureType.DescriptorPoolCreateInfo;
        }

        /// <inheritdoc />
        unsafe BaseInStructure* IChainable.PNext
        {
            get => (BaseInStructure*) PNext;
            set => PNext = value;
        }

        /// <summary>
        /// Convenience method to start a chain.
        /// </summary>
        /// <param name="capture">The newly created chain root</param>
        /// <returns>A reference to the newly created chain.</returns>
        public static unsafe ref DescriptorPoolCreateInfo Chain(
            out DescriptorPoolCreateInfo capture)
        {
            capture = new DescriptorPoolCreateInfo(StructureType.DescriptorPoolCreateInfo);
            return ref capture;
        }
    }
}
