// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.


using System;
using System.Runtime.InteropServices;
using System.Runtime.CompilerServices;
using System.Text;
using Silk.NET.Core;
using Silk.NET.Core.Native;
using Silk.NET.Core.Attributes;
using Silk.NET.Core.Contexts;
using Silk.NET.Core.Loader;

#pragma warning disable 1591

namespace Silk.NET.Vulkan
{
    [NativeName("Name", "VkExternalBufferPropertiesKHR")]
    [NativeName("AliasOf", "VkExternalBufferProperties")]
    public unsafe partial struct ExternalBufferPropertiesKHR : IChainable
    {
        public ExternalBufferPropertiesKHR
        (
            StructureType? sType = StructureType.ExternalBufferProperties,
            void* pNext = null,
            ExternalMemoryProperties? externalMemoryProperties = null
        ) : this()
        {
            if (sType is not null)
            {
                SType = sType.Value;
            }

            if (pNext is not null)
            {
                PNext = pNext;
            }

            if (externalMemoryProperties is not null)
            {
                ExternalMemoryProperties = externalMemoryProperties.Value;
            }
        }

/// <summary></summary>
        [NativeName("Type", "VkStructureType")]
        [NativeName("Type.Name", "VkStructureType")]
        [NativeName("Name", "sType")]
        public StructureType SType;
/// <summary></summary>
        [NativeName("Type", "void*")]
        [NativeName("Type.Name", "void")]
        [NativeName("Name", "pNext")]
        public void* PNext;
/// <summary></summary>
        [NativeName("Type", "VkExternalMemoryProperties")]
        [NativeName("Type.Name", "VkExternalMemoryProperties")]
        [NativeName("Name", "externalMemoryProperties")]
        public ExternalMemoryProperties ExternalMemoryProperties;

        /// <inheritdoc />
        StructureType IStructuredType.StructureType()
        {
            return SType = StructureType.ExternalBufferProperties;
        }

        /// <inheritdoc />
        unsafe BaseInStructure* IChainable.PNext
        {
            get => (BaseInStructure*) PNext;
            set => PNext = value;
        }
    }
}
