// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.


using System;
using System.Runtime.InteropServices;
using System.Runtime.CompilerServices;
using System.Text;
using Silk.NET.Core;
using Silk.NET.Core.Native;
using Silk.NET.Core.Attributes;
using Silk.NET.Core.Contexts;
using Silk.NET.Core.Loader;

#pragma warning disable 1591

namespace Silk.NET.Vulkan.Video
{
    [NativeName("Name", "StdVideoEncodeH264SliceHeader")]
    public unsafe partial struct StdVideoEncodeH264SliceHeader
    {
        public StdVideoEncodeH264SliceHeader
        (
            StdVideoEncodeH264SliceHeaderFlags? flags = null,
            StdVideoH264SliceType? sliceType = null,
            byte? seqParameterSetId = null,
            byte? picParameterSetId = null,
            ushort? idrPicId = null,
            byte? numRefIdxL0ActiveMinus1 = null,
            byte? numRefIdxL1ActiveMinus1 = null,
            StdVideoH264CabacInitIdc? cabacInitIdc = null,
            StdVideoH264DisableDeblockingFilterIdc? disableDeblockingFilterIdc = null,
            byte? sliceAlphaC0OffsetDiv2 = null,
            byte? sliceBetaOffsetDiv2 = null,
            StdVideoEncodeH264RefMemMgmtCtrlOperations* pMemMgmtCtrlOperations = null
        ) : this()
        {
            if (flags is not null)
            {
                Flags = flags.Value;
            }

            if (sliceType is not null)
            {
                SliceType = sliceType.Value;
            }

            if (seqParameterSetId is not null)
            {
                SeqParameterSetId = seqParameterSetId.Value;
            }

            if (picParameterSetId is not null)
            {
                PicParameterSetId = picParameterSetId.Value;
            }

            if (idrPicId is not null)
            {
                IdrPicId = idrPicId.Value;
            }

            if (numRefIdxL0ActiveMinus1 is not null)
            {
                NumRefIdxL0ActiveMinus1 = numRefIdxL0ActiveMinus1.Value;
            }

            if (numRefIdxL1ActiveMinus1 is not null)
            {
                NumRefIdxL1ActiveMinus1 = numRefIdxL1ActiveMinus1.Value;
            }

            if (cabacInitIdc is not null)
            {
                CabacInitIdc = cabacInitIdc.Value;
            }

            if (disableDeblockingFilterIdc is not null)
            {
                DisableDeblockingFilterIdc = disableDeblockingFilterIdc.Value;
            }

            if (sliceAlphaC0OffsetDiv2 is not null)
            {
                SliceAlphaC0OffsetDiv2 = sliceAlphaC0OffsetDiv2.Value;
            }

            if (sliceBetaOffsetDiv2 is not null)
            {
                SliceBetaOffsetDiv2 = sliceBetaOffsetDiv2.Value;
            }

            if (pMemMgmtCtrlOperations is not null)
            {
                PMemMgmtCtrlOperations = pMemMgmtCtrlOperations;
            }
        }


        [NativeName("Type", "StdVideoEncodeH264SliceHeaderFlags")]
        [NativeName("Type.Name", "StdVideoEncodeH264SliceHeaderFlags")]
        [NativeName("Name", "flags")]
        public StdVideoEncodeH264SliceHeaderFlags Flags;

        [NativeName("Type", "StdVideoH264SliceType")]
        [NativeName("Type.Name", "StdVideoH264SliceType")]
        [NativeName("Name", "slice_type")]
        public StdVideoH264SliceType SliceType;

        [NativeName("Type", "uint8_t")]
        [NativeName("Type.Name", "uint8_t")]
        [NativeName("Name", "seq_parameter_set_id")]
        public byte SeqParameterSetId;

        [NativeName("Type", "uint8_t")]
        [NativeName("Type.Name", "uint8_t")]
        [NativeName("Name", "pic_parameter_set_id")]
        public byte PicParameterSetId;

        [NativeName("Type", "uint16_t")]
        [NativeName("Type.Name", "uint16_t")]
        [NativeName("Name", "idr_pic_id")]
        public ushort IdrPicId;

        [NativeName("Type", "uint8_t")]
        [NativeName("Type.Name", "uint8_t")]
        [NativeName("Name", "num_ref_idx_l0_active_minus1")]
        public byte NumRefIdxL0ActiveMinus1;

        [NativeName("Type", "uint8_t")]
        [NativeName("Type.Name", "uint8_t")]
        [NativeName("Name", "num_ref_idx_l1_active_minus1")]
        public byte NumRefIdxL1ActiveMinus1;

        [NativeName("Type", "StdVideoH264CabacInitIdc")]
        [NativeName("Type.Name", "StdVideoH264CabacInitIdc")]
        [NativeName("Name", "cabac_init_idc")]
        public StdVideoH264CabacInitIdc CabacInitIdc;

        [NativeName("Type", "StdVideoH264DisableDeblockingFilterIdc")]
        [NativeName("Type.Name", "StdVideoH264DisableDeblockingFilterIdc")]
        [NativeName("Name", "disable_deblocking_filter_idc")]
        public StdVideoH264DisableDeblockingFilterIdc DisableDeblockingFilterIdc;

        [NativeName("Type", "int8_t")]
        [NativeName("Type.Name", "int8_t")]
        [NativeName("Name", "slice_alpha_c0_offset_div2")]
        public byte SliceAlphaC0OffsetDiv2;

        [NativeName("Type", "int8_t")]
        [NativeName("Type.Name", "int8_t")]
        [NativeName("Name", "slice_beta_offset_div2")]
        public byte SliceBetaOffsetDiv2;

        [NativeName("Type", "StdVideoEncodeH264RefMemMgmtCtrlOperations *")]
        [NativeName("Type.Name", "StdVideoEncodeH264RefMemMgmtCtrlOperations *")]
        [NativeName("Name", "pMemMgmtCtrlOperations")]
        public StdVideoEncodeH264RefMemMgmtCtrlOperations* PMemMgmtCtrlOperations;
    }
}
